@@ -31,10 +31,15 @@ else:
     setup()
 
 
- 
-
-
 def get_keywords(dataFrame):
+    """Add a new column to the dataFrame with all the keywords defined as NOUN or fit with the spacy Matcher.
+    
+     Args:
+        dataFrame (dataFrame, required): dataFrame with news in PySophia2 structure
+        
+    Returns:
+        None
+    """
     new_row=np.zeros(len(dataFrame.index))
     dataFrame['keywords']=new_row
     for index,row in dataFrame.iterrows():
@@ -55,6 +60,16 @@ def get_keywords(dataFrame):
         dataFrame.loc[index,'keywords']=filteredText
         
 def get_frequency(df):
+    
+    """Create a dictionary with the frequency for the terms in Keyword column.
+    
+     Args:
+        dataFrame (dataFrame, required): dataFrame with news in PySophia2 structure
+        
+    Returns:
+        Dict: it has a Counter with the times that each word appears on the keywords for the news.
+    """
+    
     if "keywords" not in df:
         get_keywords(df)
     concept_freq_total=Counter({})
@@ -68,6 +83,15 @@ def get_frequency(df):
     return {"total_news":len(df),"total_elements": sum(concept_freq_total.values()), "dictionary": concept_freq_total}
 
 def group_by_date(dataset, granularity="month"):
+    """Group a set of news by a period.
+    
+     Args:
+        dataset (dataFrame, required): dataFrame with news in PySophia2 structure
+        granularity (string, required): could be day/month/year. Default: Month
+        
+    Returns:
+        group_by: return a pandas groupby struct with all the news grouped by a period.
+    """
     if granularity == "month":
         return dataset.groupby(by=["month","year"])
     if granularity == "year":
@@ -77,27 +101,47 @@ def group_by_date(dataset, granularity="month"):
     
     
 def calculateDist(dataset,group_by="month"):
+    """Calculte the frequency distribution for a pysophia2 dataset grouped in periods.
+    
+     Args:
+        dataset (dataFrame, required): dataFrame with news in PySophia2 structure
+        group_by (string, required): could be day/month/year. Default: Month
+        
+    Returns:
+        Sophia2WordDistributionStruct: a struct with the frecuency of keywords for each periods in a set of news.
+    """
     if "keywords" not in dataset:
         get_keywords(dataset)
     dataset_=dataset.copy()
     dataset_["month"]=dataset_['date'].apply(lambda x: x.split("-")[1])
     dataset_["year"]=dataset_['date'].apply(lambda x: x.split("-")[0])
     gb_dataset=group_by_date(dataset_, group_by)
-    sophia2_ngram_struct = {}
+    pySophia2WordDistribution = {}
     if group_by == "day":
         for key, ds in gb_dataset:
-            sophia2_ngram_struct[datetime.strptime(key, '%Y-%m-%d').strftime("%Y/%m/%d")] = get_frequency(ds)
+            pySophia2WordDistribution[datetime.strptime(key, '%Y-%m-%d').strftime("%Y/%m/%d")] = get_frequency(ds)
     elif group_by == "month":
         for (month,year), ds in gb_dataset:
-            sophia2_ngram_struct[(str(year)+"/"+str(month))] = get_frequency(ds)
+            pySophia2WordDistribution[(str(year)+"/"+str(month))] = get_frequency(ds)
     elif group_by == "year":
         for year, ds in gb_dataset:
-            sophia2_ngram_struct[str(year)] = get_frequency(ds)
-    else: return "Wrong granularity parameter, please use 'day', 'month' or 'year' as granularity parameter instead of "+granularity
+            pySophia2WordDistribution[str(year)] = get_frequency(ds)
+    else: return "Wrong granularity parameter, please use 'day', 'month' or 'year' as granularity parameter instead of "+group_by
     
-    return sophia2_ngram_struct
+    return pySophia2WordDistribution
 
-def view(word_distribution, words, annotate, normalize=True): ##to word_distribution
+def view(word_distribution, words, annotate=False, normalize=True): 
+    """Graph the frecuency term for a set of words, it could be normalized by the news in each period, or calculated in total times appearances.
+    
+     Args:
+        word_distribution (Sophia2WordDistribution, required): struct calculated through calculateDist function.
+        words ([string], required): words to be displayed on the graph.
+        annotate (bool,optional): show the point over the graph. Default: False.
+        normalize=(bool, optional): allow to normalize the quantity of appearances by the total news in that period. Default: True.
+        
+    Returns:
+        None
+    """
     ngram_dictionary={}
     for palabra in words:
         ngram_dictionary[palabra]=[]
@@ -114,7 +158,7 @@ def view(word_distribution, words, annotate, normalize=True): ##to word_distribu
         plt.legend(loc=5, bbox_to_anchor=(1.3, 0.5), fancybox=True, shadow=True )
         plt.title("PySophia2 NGramViewer")
         if(annotate):
-            for xy in zip(keys, ngram_dictionary[palabra]):                                       # <--
+            for xy in zip(keys, ngram_dictionary[palabra]):                               
                 plt.annotate(('%.2f' % xy[1]), xy=xy, textcoords='data')
     plt.xlabel('Date', fontsize=12)
     plt.ylabel('Frequency', fontsize=12)
@@ -122,22 +166,19 @@ def view(word_distribution, words, annotate, normalize=True): ##to word_distribu
     plt.rcParams['figure.figsize'] = [7, 7]
     
     
-def get_n_most_freq(freq_struct, n, graph=False):
-    '''provides a list with all the countries that currently have media outlets in Sun
-
-    Returns:
-        [string]: [country_name]
-    '''
-    dict_orders = sorted(freq_struct["dictionary"].items(), key=lambda x: x[1], reverse=True)
-    if graph:
-        
-        x = [x[0] for x in dict_orders[:n]]
-        y = [x[1]/freq_struct["total_elements"] for x in dict_orders[:n]]
-        plt.bar(x,y)
-        plt.title("term frequency top %i words" %(n))
-    return dict_orders[:n]
-
 def freq(word_distribution,top_n=None, words=None, graph=True):
+    fig, ax = plt.subplots()
+    """return the frequency for a top_n words or a arbitrary array of words. It can be graphed.
+    
+     Args:
+        word_distribution (Sophia2WordDistribution, required): struct calculated through calculateDist function.
+        top_n (int,optional): quantity of the top words you want to get.
+        words ([string], required): list words.
+        graph (bool, optional): activate or deactivate the graph.
+        
+    Returns:
+        None
+    """
     concept_freq_total=Counter({})
     total_news=0
     for a in word_distribution:
@@ -153,16 +194,17 @@ def freq(word_distribution,top_n=None, words=None, graph=True):
         
             x = [x[0] for x in top]
             y = [x[1]/total_news for x in top]
-            plt.bar(x,y)
-            plt.title("Term frecuency top %i words" %(top_n))
+            ax.bar(x,y)
+            ax.title("Term frecuency top %i words" %(top_n))
         return top
     elif words!=None:
         y = []
         for word in words:
             y.append(concept_freq_total[word]/total_news)
-        plt.bar(words,y)
-        plt.title("Term frecuency bar graph")
-        plt.xticks(rotation=90)
+        ax.bar(words,y)
+        ax.set_title("Term frecuency bar graph")
+        ax.set_ylabel('Frequency', fontsize=12)
+        ax.set_xticks(rotation=90)
         
         
 
